package Alien::cares;
use 5.012;

our $VERSION = "1.1.1.3";

use XS::Loader;

XS::Loader::load_noboot();

1;
